@@ -6,7 +6,7 @@ use warnings;
 use DBI '1.605';
 use DBIx::Connector::Driver;
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 my $die = sub { die @_ };
 
@@ -140,11 +140,19 @@ sub disconnect {
     return $self;
 }
 
+my %WARNED;
+
 sub _errh {
-    !$_[0] ? $die
-           : $_[0]     eq 'catch' ? $_[1]
-           : ref $_[0] eq 'CODE'  ? $_[0]
-           :                        $die;
+    return $die if !$_[0]
+        || ($_[0] ne 'catch' && ref $_[0] ne 'CODE');
+
+    unless ($WARNED{+caller}++) {
+        require Carp && Carp::carp(
+            'Use of "catch" blocks has been deprecated as of DBIx::Connector 0.46. Please use Try::Tiny instead.'
+        );
+    }
+
+    return $_[0]  eq 'catch' ? $_[1] : $_[0];
 }
 
 sub run {
@@ -352,7 +360,7 @@ sub svp {
 
 PROXY: {
     package DBIx::Connector::Proxy;
-    our $VERSION = '0.45';
+    our $VERSION = '0.46';
 
     sub new {
         require Carp;
@@ -601,6 +609,10 @@ won't be sorry, I promise.
 
 =head3 Exception Handling
 
+B<NOTE: This feature is deprecated as of DBIx::Connector 0.46 and will be
+removed by September, 2011. Please update your modules to use L<Try::Tiny>,
+instead.>
+
 Another optional feature of the execution methods L<C<run()>|/"run">,
 L<C<txn()>|/"txn">, and L<C<svp()>|/"svp"> is integrated exception handling.
 This is especially valuable if the DBI C<RaiseError> attribute is true, or if
